DialogMessages class

Constructors

DialogMessages({String? hint, String? notRecognized, String? success, String? cancel, String? title, String? requiredTitle, String? settings, String? settingsDescription, String? lockOut, String? goToSettingsButton, String? goToSettingsDescription, String? cancelButton})
const

Properties

cancel → String?
final
cancelButton → String?
final
goToSettingsButton → String?
final
goToSettingsDescription → String?
final
hashCode → int
The hash code for this object.
no setterinherited
hint → String?
final
lockOut → String?
final
messages → Map<String, String>
no setter
notRecognized → String?
final
requiredTitle → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
settings → String?
final
settingsDescription → String?
final
success → String?
final
title → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited